package com.ruoyi.wx.web.service.impl;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.framework.recovery.domain.RecCommodity;
import com.ruoyi.framework.recovery.domain.RecContent;
import com.ruoyi.framework.recovery.domain.RecSaleInfo;
import com.ruoyi.framework.recovery.domain.RecStores;
import com.ruoyi.framework.recovery.mapper.RecCommodityMapper;
import com.ruoyi.framework.recovery.mapper.RecSaleInfoMapper;
import com.ruoyi.framework.recovery.service.IRecContentService;
import com.ruoyi.framework.recovery.service.IRecSaleInfoService;
import com.ruoyi.wx.web.domain.vo.RecStoresVo;
import com.ruoyi.wx.web.domain.vo.SaleInfoVo;
import com.ruoyi.wx.web.mapper.WxHomeMapper;
import com.ruoyi.wx.web.service.IWxHomeService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.concurrent.*;
import java.util.stream.Collectors;

@Service
public class WxHomeServiceImpl implements IWxHomeService {
    @Autowired
    private IRecSaleInfoService recSaleInfoService;

    @Autowired
    private IRecContentService recContentService;

    @Autowired
    private RecSaleInfoMapper saleInfoMapper;

    @Autowired
    private WxHomeMapper wxHomeMapper;

    private final static ArrayBlockingQueue<Runnable> WORK_QUEUE = new ArrayBlockingQueue<>(9);

    private final static RejectedExecutionHandler HANDLER = new ThreadPoolExecutor.CallerRunsPolicy();

    @SuppressWarnings("unused")
    private static ThreadPoolExecutor executorService = new ThreadPoolExecutor(9, 9, 1000, TimeUnit.MILLISECONDS,
            WORK_QUEUE, HANDLER);

    @Override
    public AjaxResult getIndex() throws ExecutionException, InterruptedException {
        AjaxResult result = new AjaxResult();
        // 发售信息
        Callable<List<RecSaleInfo>> saleInfoCallable = () -> recSaleInfoService.selectRecSaleInfoList(new RecSaleInfo());
        // 评论
        Callable<List<RecContent>> contentCallable = () -> recContentService.selectRecContentList(new RecContent());
        // 热门发售

        FutureTask<List<RecSaleInfo>> saleInfoTask = new FutureTask<>(saleInfoCallable);
        FutureTask<List<RecContent>> contentTask = new FutureTask<>(contentCallable);

        executorService.submit(saleInfoTask);
        executorService.submit(contentTask);
        result.put("saleInfo", saleInfoTask.get());
        result.put("content", contentTask.get());
        return result;
    }

    @Override
    public List<SaleInfoVo> getSaleInfo(Long id) {
        RecSaleInfo saleInfo = saleInfoMapper.selectRecSaleInfoById(id);
        // 获取到商品id，并将商品id转换为Integer到数据库中查询
        List<String> ids = Arrays.asList(saleInfo.getCommodityId().split(","));
        List<Integer> comIds = ids.stream().map(Integer::parseInt).toList();

        // 获取所有商品内容
        List<SaleInfoVo> infoVos = wxHomeMapper.selectRecCommodityByIds(comIds);
        // 根据商品获取所有门店信息
        List<RecStores> stores = wxHomeMapper.selectRecStoresByCommondityIds(ids);
        Map<Long, List<RecStores>> storesMap = new ConcurrentHashMap<>();
        // 根据根据商品id筛选出相应的门店
        for (SaleInfoVo infoVo : infoVos) {
            List<RecStores> recStores = new ArrayList<>();
            for (RecStores store : stores) {
                if (store.getCommondityId().contains(String.valueOf(infoVo.getId()))) {
                    recStores.add(store);
                }
            }
            storesMap.put(infoVo.getId(), recStores);
        }
        // 拼接门店信息和商品信息
        for (SaleInfoVo infoVo : infoVos) {
            for (Map.Entry<Long, List<RecStores>> entry : storesMap.entrySet()) {
                if (Objects.equals(entry.getKey(), infoVo.getId())) {
                    Map<String, List<RecStores>> cityMap = entry.getValue().stream().filter(vo -> StringUtils.isNotEmpty(vo.getCity())).collect(Collectors.groupingBy(RecStores::getCity));
                    List<RecStoresVo> storesVos = new ArrayList<>();
                    cityMap.forEach((key, value) -> {
                        RecStoresVo recStoresVo = new RecStoresVo();
                        recStoresVo.setCity(key);
                        recStoresVo.setStores(value);
                        storesVos.add(recStoresVo);
                    });
                    infoVo.setStores(storesVos);
                }
            }
        }
        return infoVos;
    }
}
